<?php
/**
 * Yii blog
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */
 
class BlogController extends Controller
{
	public $loginForm;
	public $posts;
	public $postCount;
	public $languages;

	// Variables used in the <head>
	public $metaKeywords;
	public $metaDescription;
	public $metaRobots;
	public $canonical;
			
	public function init()
	{
		parent::init();
		
        Yii::$classMap = array_merge( Yii::$classMap, array(
            'CaptchaExtendedAction' => Yii::getPathOfAlias('blog.extensions.captchaExtended').DIRECTORY_SEPARATOR.'CaptchaExtendedAction.php',
            'CaptchaExtendedValidator' => Yii::getPathOfAlias('blog.extensions.captchaExtended').DIRECTORY_SEPARATOR.'CaptchaExtendedValidator.php'
        ));
	}
	
	public function beforeAction($action)
	{
		parent::beforeAction($action);
		
		// The flags will only be displayed if the blog has posts...............
		if(isset($_GET['category']) && isset($_GET['post']))
		{
			$this->posts = Post::model()->with('category')->with('lang')->findAll(array(
			'condition' => 'lang.status = 1 AND t.category_id = ? AND t.id = ? AND t.status =' . Post::STATUS_PUBLISHED . ' AND category.status ='. Category::STATUS_PUBLISHED,
			'order' => 't.language ASC',
			'params' => array($_GET['category'], $_GET['post'])));
		}
		elseif(Yii::app()->controller->id === 'post' && $action->id == 'index')
		{
			$this->postCount = Post::model()->with('category')->with('lang')->findAll(array(
			'select' => 't.language, count(*) as postCount',
			'group' => 't.language',
			'condition' => 'lang.status = 1 AND t.status =' . Post::STATUS_PUBLISHED . ' AND category.status ='. Category::STATUS_PUBLISHED,
			'having' => 'postCount > 0',
			'order' => 't.language ASC'));
		}
		
		// Blog: Checking whether user should be banned or not...
		if(!Yii::app()->user->isGuest && User::model()->find('id=?', array(Yii::app()->user->id))->status == User::STATUS_BANNED)
		{
			$username = Yii::app()->user->name;
			Yii::app()->user->logout();
			$this->redirect(array('/blog/site/banned', 'lang' => Yii::app()->getLanguage(), 'username' => $username));
		}

		$this->loginForm=new LoginForm;
		if(isset($_POST['LoginForm']))
		{
			$this->loginForm->attributes=$_POST['LoginForm'];
			if($this->loginForm->validate() && $this->loginForm->login())
			{
				$this->redirect(array('/blog/post/index', 'lang' => Yii::app()->getLanguage()));
			}
			else
			{
				$user = User::model()->find('username=?', array($_POST['LoginForm']['username']));
				if(!is_null($user) && CPasswordHelper::verifyPassword($this->loginForm->password, $user->password))
				{
					if($user->status == User::STATUS_BANNED)
						$this->redirect(array('/blog/site/banned', 'lang' => Yii::app()->getLanguage(), 'username' => $user->username));
				}
			}
		}
		
		$this->paramKeys = array_keys($_GET);
		$this->paramValues = array_values($_GET);

		$this->languages = Language::model()->findAll(array('order' => 'code ASC'));

		if(isset($_POST['search']))
			$this->redirect(array('/blog/post/search', 'search' => $_POST['search'], 'lang' => Yii::app()->getLanguage()));	
		
		return true;
	}

	function printBlogFlags()
	{
		if(!is_null($this->postCount))
		{
			foreach ($this->postCount as $post)
			{
				$arrayUrl = array();
				$arrayUrl[0] = Yii::app()->controller->id . '/' . Yii::app()->controller->action->id;
				$arrayUrl['lang'] = $post->language;	
				echo CHtml::link(CHtml::image($this->module->assetsUrl . '/images/flags/' . $post->language . '.gif',$post->language								
					,array('class' => (Yii::app()->language === $post->language ? 'flag selectedflag wobble' : 'flag wobble')))
					,$arrayUrl);
			}			
		}
		elseif(!is_null($this->posts))
		{
			foreach ($this->posts as $post)
			{
				echo CHtml::link(CHtml::image($this->module->assetsUrl . '/images/flags/' . $post->language . '.gif',$post->language								
					,array('class' => (Yii::app()->language === $post->language ? 'flag selectedflag wobble' : 'flag wobble')))
					,$post->url);
			}
		}
		else
		{
			foreach($this->languages as $key => $language)
			{
				$arrayUrl = array();					

				$arrayUrl[0] = Yii::app()->controller->id . '/' . Yii::app()->controller->action->id;
			 	for($i = 0; $i < count($this->paramKeys); $i++)
					if($this->paramKeys[$i] !== 'lang')
			 			$arrayUrl[$this->paramKeys[$i]] = $this->paramValues[$i];
				$arrayUrl['lang'] = $language->code;
				
				echo CHtml::link(CHtml::image($this->module->assetsUrl . '/images/flags/' . $language->code . '.gif', $language->code								
					,array('class' => (Yii::app()->language === $language->code ? 'flag selectedflag wobble' : 'flag wobble')))
					,$arrayUrl);
			}
		}
	}
}
	