<?php
/**
 * Yii blog
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */
 
/**
 * UserIdentity represents the data needed to identity a user.
 * It contains the authentication method that checks if the provided
 * data can identity the user.
 */
class UserIdentity extends CUserIdentity
{
	const ERROR_USER_BANNED=3;
	const ERROR_USER_UNCONFIRMED=4;
	private $_id;

	/**
	 * Authenticates a user.
	 * @return boolean whether authentication succeeds.
	 */
	public function authenticate()
	{
		$user=User::model()->find('LOWER(username)=?',array(strtolower($this->username)));
		if($user===null)
			$this->errorCode=self::ERROR_USERNAME_INVALID;
		else if(!CPasswordHelper::verifyPassword($this->password, $user->password))
			$this->errorCode=self::ERROR_PASSWORD_INVALID;
		else
		{
			$user->scenario = "login";
			if($user->status == User::STATUS_BANNED)
			{
				if(!is_null($user->ban_expires) && $user->ban_expires < time())
				{		
					$user->status = User::STATUS_ACTIVE;
					$user->ban_expires = null;
					$user->ban_reason = null;
					$user->last_visit = time();
					$user->save();
					$this->_id=$user->id;
					$this->username=$user->username;
					$this->errorCode=self::ERROR_NONE;				
				}
				else {
					$this->errorCode=self::ERROR_USER_BANNED;
				}
			}
			elseif($user->status == User::STATUS_UNCONFIRMED)
			{
				$this->errorCode=self::ERROR_USER_UNCONFIRMED;
			}
			else 
			{
				$user->last_visit = time();
				$user->save();
				$this->_id=$user->id;
				$this->username=$user->username;
				$this->errorCode=self::ERROR_NONE;
			}

		}
		return $this->errorCode==self::ERROR_NONE;
	}

	/**
	 * @return integer the ID of the user record
	 */
	public function getId()
	{
		return $this->_id;
	}
}