<?php
/**
 * Yii blog
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */
 
class CategoryController extends BlogController
{
	public $layout = '/layouts/blog';
	/**
	 * @var CActiveRecord the currently loaded data model instance.
	 */
	private $_model;
	/**
	 * @return array action filters
	 */
	public function filters()
	{
		$filters = array(
			'accessControl', // perform access control for CRUD operations
		);
		
		return array_merge($filters, parent::filters());
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow', // allow admin users to access all actions
				'roles'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}
	
	/**
	 * Creates a new model.
	 */
	public function actionCreate()
	{
		$model=new Category;
		if(isset($_POST['Category']))
		{
			$model->attributes=$_POST['Category'];
			if($model->save())
			{
				Yii::app()->user->setFlash('success', Message::getTranslation(78));
				$this->redirect(array('admin', 'lang' => $_POST['lang']));
			}
		}

		$languages = Language::model()->findAll(array('order' => 'code ASC'));

        $category = Category::model()->find(array('select' => 'MAX(id) as maxId', 'condition' => 'language = ?', 'params' => array($languages[0]->code)));
        $model->id = $category->maxId + 1;
        $model->language = $languages[0]->code;
        
		$this->render('create',array(
			'language' => $languages[0]->code,
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 */
	public function actionUpdate()
	{
		$model=$this->loadModel();
		$model->scenario = 'update';
		if(isset($_POST['Category']))
		{
			$model->attributes=$_POST['Category'];
			if($model->save())
			{
				Yii::app()->user->setFlash('success',Message::getTranslation(79));
				$this->redirect(array('admin', 'lang' => $_POST['lang']));
			}
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 */
	public function actionDelete()
	{
		// we only allow deletion via POST request
		if($this->loadModel()->delete()){
			Yii::app()->user->setFlash('success',Message::getTranslation(80));			
		}
		else {
			Yii::app()->user->setFlash('error',Message::getTranslation(81));						
		}

		$this->redirect(array('admin', 'lang' => $_GET['lang']));
	}
	
	
	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Category('search');
		$model->unsetAttributes();
		if(isset($_GET['Category']))
			$model->attributes=$_GET['Category'];
		$this->render('admin',array(
			'model'=>$model,
		));
	}


	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 */
	public function loadModel()
	{
		if($this->_model===null)
		{
			if(isset($_GET['category']) && isset($_GET['language']) )
			{
				if(Yii::app()->user->isGuest)
					$condition='status='.Category::STATUS_PUBLISHED;
				else
					$condition='';
				$this->_model=Category::model()->findByPk(array('id' => $_GET['category'], 'language' => $_GET['language']), $condition);
			}
			if($this->_model===null)
				throw new CHttpException(404,Message::getTranslation(94));
		}
		return $this->_model;
	}

	public function actionCategoriesByLanguage()
	{
		$categories = Category::model()->findAll(array('condition' => 'language =\'' . $_POST['Category']['language'] . '\' AND category_id IS NULL','order' => 'LOWER(name) ASC'));
		echo "<option value=''>" . Message::getTranslation(95) . "</option>";
		$this->printOptions($categories, 0, $_POST['Category']['id']);
	}
	
	private function printOptions($categories, $level, $id)
	{			
		foreach($categories as $category)
		{
			$lines = '';
			for($i = 0; $i < $level; $i++)
				$lines .= '--';
			echo "<option " . ($category->id == $id ? 'disabled' : '') . " value=\"{$category->id}\">{$lines}{$category->name}</option>";
			$this->printOptions($category->categories, $level + 1, $id);
		}		
	}
    
    public function actionGetMaxId()
    {
        if(isset($_POST['language']))
        {
            $category = Category::model()->find(array('select' => 'MAX(id) as maxId', 'condition' => 'language = ?', 'params' => array($_POST['language'])));
            echo $category->maxId + 1;
        }       
    }
}
