<?php
/**
 * Yii blog
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */
 
class CommentController extends BlogController
{
	public $layout = '/layouts/blog';

	/**
	 * @var CActiveRecord the currently loaded data model instance.
	 */
	private $_model;
	
	/**
	 * @return array action filters
	 */
	public function filters()
	{
		$filters = array(
			'accessControl', // perform access control for CRUD operations
		);
		
		return array_merge($filters, parent::filters());
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',
				'actions' => array('update','admin'),
				'roles'=>array('reader','author', 'editor', 'publisher'),
			),
			array('allow', // allow admin users to access all actions
				'roles'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Updates a particular model.
	 */
	public function actionUpdate()
	{
		$model=$this->loadModel();
		
		if( Yii::app()->user->checkAccess('admin') || ((Yii::app()->user->checkAccess('reader') 
		|| Yii::app()->user->checkAccess('author') || Yii::app()->user->checkAccess('editor')
		|| Yii::app()->user->checkAccess('publisher')) && $model->user_id == Yii::app()->user->id ))
		{
			if(!Yii::app()->user->checkAccess('admin'))
				$model->status = Comment::STATUS_PENDING;
			
			if(is_null($model->user_id))
				$model->scenario = 'updateguest';
			else 
				$model->scenario = 'updateuser';
			
			if(isset($_POST['ajax']) && $_POST['ajax']==='comment-form')
			{
				echo CActiveForm::validate($model);
				Yii::app()->end();
			}
			if(isset($_POST['Comment']))
			{
				$model->attributes=$_POST['Comment'];
				if($model->save())
				{
					Yii::app()->user->setFlash('success',Message::getTranslation(76));
					$this->redirect(array('admin', 'lang' => $_POST['lang']));
				}
			}
	
			$this->render('update',array(
				'model'=>$model,
			));
		}
		else {
			throw new CHttpException(404,Message::getTranslation(94));
		}
	}

	/**
	 * Deletes a particular model.
	 */
	public function actionDelete()
	{
		if($this->loadModel()->delete()){
			Yii::app()->user->setFlash('success',Message::getTranslation(77));
		}
		else {
			Yii::app()->user->setFlash('error', Message::getTranslation(93));							
		}
		$this->redirect(array('admin', 'lang' => $_GET['lang']));
	}
	
	
	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Comment('search');
		$model->unsetAttributes();
		if(isset($_GET['Comment']))
			$model->attributes=$_GET['Comment'];
		$this->render('admin',array(
			'model'=>$model,
		));
	}
	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('Comment', array(
			'criteria'=>array(
				'with'=>'post',
				'order'=>'t.status, t.create_time DESC',
			),
			'pagination'=>array(
				'pageSize'=>Parameter::getValue(9),
			),
		));

		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Approves a particular comment.
	 */
	public function actionApprove()
	{
		$comment=$this->loadModel();
		$comment->approve();
		Yii::app()->user->setFlash('success',Message::getTranslation(96));
		$this->redirect(array('admin', 'lang' => $_GET['lang']));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 */
	public function loadModel()
	{
		if($this->_model===null)
		{
			if(isset($_GET['comment']) && isset($_GET['post']) && isset($_GET['category']) && isset($_GET['language']))
				$this->_model=Comment::model()->findbyPk(array('id' => $_GET['comment'], 'post_id' => $_GET['post'], 'category_id' => $_GET['category'], 'language' => $_GET['language'], ));
			if($this->_model===null)
				throw new CHttpException(404,Message::getTranslation(94));
		}
		return $this->_model;
	}
}
