<?php
/**
 * Yii blog
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */
 
class MessageController extends BlogController
{
	public $layout = '/layouts/blog';
	/**
	 * @var CActiveRecord the currently loaded data model instance.
	 */
	private $_model;
	/**
	 * @return array action filters
	 */
	public function filters()
	{
		$filters = array(
			'accessControl', // perform access control for CRUD operations
		);
		
		return array_merge($filters, parent::filters());
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow', // allow admin users to access all actions
				'roles'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Creates a new model.
	 */
	public function actionCreate()
	{
		$model=new Message;
		if(isset($_POST['Message']))
		{
			$model->attributes=$_POST['Message'];
			if($model->save())
			{
				Yii::app()->user->setFlash('flash',Message::getTranslation(89));
				$this->redirect(array('admin', 'lang' => $_POST['lang']));
			}
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 */
	public function actionUpdate()
	{
		$model=$this->loadModel();
		
		if(isset($_POST['Message']))
		{
			$model->attributes=$_POST['Message'];

			if($model->save())
			{
				Yii::app()->user->setFlash('flash',Message::getTranslation(90));
				$this->redirect(array('admin', 'lang' => $_POST['lang']));
			}
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 */
	public function actionDelete()
	{
		// we only allow deletion via POST request
		$this->loadModel()->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
		{
			Yii::app()->user->setFlash('flash',Message::getTranslation(91));
			$this->redirect(array('admin', 'lang' => $_GET['lang']));
		}
	}
	
	
	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Message('search');
		$model->unsetAttributes();
		if(isset($_GET['Message']))
			$model->attributes=$_GET['Message'];
		$this->render('admin',array(
			'model'=>$model,
		));
	}


	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 */
	public function loadModel()
	{
		if($this->_model===null)
		{
			if(isset($_GET['message']))
			{
				$this->_model=Message::model()->findByPk(array('id' => $_GET['message'], 'language' => $_GET['language']));
			}
			if($this->_model===null)
				throw new CHttpException(404,Message::getTranslation(94));
		}
		return $this->_model;
	}
}
