<?php
/**
 * Yii blog
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */
 
class PostController extends BlogController
{
	public $layout = '/layouts/blog';

	/**
	 * Declares class-based actions.
	 */
	public function actions()
	{
		return array(
			// captcha action renders the CAPTCHA image displayed on the contact page
			'captcha'=>array(
                'class'=>'CaptchaExtendedAction',
                // if needed, modify settings
                'testLimit' => 1,
                'mode'=>CaptchaExtendedAction::MODE_MATH,
			),
		);
	}
		
	/**
	 * @return array action filters
	 */
	public function filters()
	{
		$filters = array(
			'accessControl', // perform access control for CRUD operations
		);
		
		return array_merge($filters, parent::filters());
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',
				'actions'=>array('index','view','captcha','search'),
				'users'=>array('*'),
			),
			array('allow',
				'roles'=>array('admin'),
			),
			array('allow',
				'actions' => array('create', 'update', 'delete', 'admin', 'categoriesByLanguage', 'suggestTags', 'getMaxId'), 
				'roles'=> array('author', 'editor', 'publisher'),
			),
			array('deny',
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 */
	public function actionView()
	{
		$post=null;
		
		if(isset($_GET['post']) && isset($_GET['category']) && isset($_GET['lang']))
		{
			if(Yii::app()->user->checkAccess('admin') || Yii::app()->user->checkAccess('publisher') || Yii::app()->user->checkAccess('editor'))
				$condition='';
			elseif(Yii::app()->user->checkAccess('author'))
				$condition='status='.Post::STATUS_PUBLISHED . ' OR user_id=' . Yii::app()->user->id;
			elseif(Yii::app()->user->checkAccess('reader') || Yii::app()->user->isGuest)
				$condition='status='.Post::STATUS_PUBLISHED;
			
			$post=Post::model()->findByPk(array('id' => $_GET['post'], 'category_id' => $_GET['category'], 'language' => $_GET['lang']), $condition);
			
			if(!is_null($post) && (Yii::app()->user->checkAccess('reader') || Yii::app()->user->isGuest))
			{
				$category = $post->category;
				while(true)
				{
					if($category->status == Category::STATUS_UNPUBLISHED)
					{
						$post = null;
						break;
					}
					if(is_null($category->category_id))
						break;
					$category = $category->category;
				}
			}
		}
		if($post===null)
			throw new CHttpException(404,Message::getTranslation(94));		
	
		
		$comment=new Comment;
		if(Yii::app()->user->isGuest)
			$comment->scenario = "guestcomment";
		if(isset($_POST['ajax']) && $_POST['ajax']==='comment-form')
		{
			echo CActiveForm::validate($comment);
			Yii::app()->end();
		}
		if(isset($_POST['Comment']))
		{
			$comment->attributes=$_POST['Comment'];
			if($post->addComment($comment))
			{
				if($comment->status==Comment::STATUS_PENDING)
					Yii::app()->user->setFlash('commentSubmitted',Message::getTranslation(75));
				$this->refresh();
			}
		}

		$comments = new CActiveDataProvider('Comment',array(
            'criteria'=>array(                   
              	'order'=>'create_time DESC',
				'condition' =>
		             'post_id = ' . $post->id . ' AND category_id = ' . $post->category_id . 
		             ' AND language = "' . $post->language . '" AND status = ' . Comment::STATUS_APPROVED . 
		             ' AND comment_id IS NULL'		
            ),
			'pagination'=>array(
				'pageSize'=>Parameter::getValue(33),
			),
		));

		$this->render('view',array(
			'model'=>$post,
			'comment'=>$comment,
			'comments' => $comments,
		));
	}

	/**
	 * Creates a new model.
	 */
	public function actionCreate()
	{
		$model=new Post;
		$model->meta_keywords = null;
		$model->meta_description = null;
		$model->status = Post::STATUS_DRAFT;
		$model->user_id = Yii::app()->user->id;
		
		if(isset($_POST['Post']))
		{
			$model->attributes=$_POST['Post'];
			if($model->save())
			{
				Yii::app()->user->setFlash('success',Message::getTranslation(72));
				$this->redirect(array('admin', 'lang' => $_POST['lang']));
			}
		}

		$languages = Language::model()->findAll(array('order' => 'code ASC'));

		$this->render('create',array(
			'language' => $languages[0]->code,
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 */
	public function actionUpdate()
	{
		$model=null;
		
		if(isset($_GET['post']) && isset($_GET['category']) && isset($_GET['language']))
		{
			if(Yii::app()->user->checkAccess('admin') || Yii::app()->user->checkAccess('publisher') || Yii::app()->user->checkAccess('editor'))
				$condition='';
			elseif(Yii::app()->user->checkAccess('author'))
				$condition='user_id=' . Yii::app()->user->id;
			
			$model=Post::model()->findByPk(array('id' => $_GET['post'], 'category_id' => $_GET['category'], 'language' => $_GET['language']), $condition);
		}
		if($model===null)
			throw new CHttpException(404,Message::getTranslation(94));
		
		$model->scenario = 'update';
		if(isset($_POST['Post']))
		{
			$model->attributes=$_POST['Post'];
			if($model->save())
			{
				Yii::app()->user->setFlash('success',Message::getTranslation(73));
				$this->redirect(array('admin', 'lang' => $_POST['lang']));
			}
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 */
	public function actionDelete()
	{
		$model=null;
		
		if(isset($_GET['post']))
		{
			if(Yii::app()->user->checkAccess('admin')  || Yii::app()->user->checkAccess('publisher') || Yii::app()->user->checkAccess('editor'))
				$condition='';
			elseif(Yii::app()->user->checkAccess('author'))
				$condition='user_id=' . Yii::app()->user->id;
			
			$model=Post::model()->findByPk(array('id' => $_GET['post'], 'category_id' => $_GET['category'], 'language' => $_GET['language']), $condition);
		}
		if($model === null)
			throw new CHttpException(404,Message::getTranslation(94));
		

		if($model->delete())
			Yii::app()->user->setFlash('success',Message::getTranslation(74));
		else
			Yii::app()->user->setFlash('error',Message::getTranslation(144));
		
		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
		{	
			$this->redirect(array('admin', 'lang' => $_GET['lang']));
		}
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		if(!isset($_GET['lang']))
			throw new CHttpException(404,Message::getTranslation(94));
		
		$categories = '';
		$language = $_GET['lang'];
		
		if(isset($_GET['category']))
		{
			$category = Category::model()->findByPk(array('id' => $_GET['category'], 'language' => $language), array('condition' => 'status = ' . Category::STATUS_PUBLISHED));
			if(!is_null($category))
				$categories = $category->id . Category::getSubcategoriesIdsR($category->categories);		
		}		
		else
			$categories = substr(Category::getSubcategoriesIdsR(Category::model()->findAll(array('condition' => 'language =:language AND category_id IS NULL','order' => 'LOWER(name) ASC', 'params' => array(':language' => $language)))),1);
		
		$params = array();
		$params['language'] = $language;
		if(isset($_GET['year']))
			$params['year'] = $_GET['year'];
		if(isset($_GET['month']))
			$params['month'] = $_GET['month'];	
			
		$criteria=new CDbCriteria(array(
			'condition'=>'status='.Post::STATUS_PUBLISHED . ' AND language=:language AND category_id IN('. $categories .')' . (isset($_GET['year']) ? ' AND strftime("%Y", datetime(create_time, "unixepoch")) = :year': '') . (isset($_GET['month']) ? ' AND strftime("%m", datetime(create_time, "unixepoch")) = :month' : ''),
			'order'=>'id DESC',
			'params'=>$params
		));			
			
		if(isset($_GET['tag']))
			$criteria->addSearchCondition('tags', str_replace('-',' ',$_GET['tag']));

		$dataProvider=new CActiveDataProvider('Post', array(
			'pagination'=>array(
				'pageSize'=>Parameter::getValue(4),
			),
			'criteria'=>$criteria,
		));

		if(count($dataProvider->getData()) == 0 && Yii::app()->getLanguage() !== Parameter::getValue(29))
			$this->redirect(array('post/index', 'lang' => Parameter::getValue(29)));
		
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}
	
	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Post('search');
		$model->unsetAttributes();
		if(isset($_GET['Post']))
			$model->attributes=$_GET['Post'];
		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Suggests tags based on the current user input.
	 * This is called via AJAX when the user is entering the tags input.
	 */
	public function actionSuggestTags()
	{
		if(isset($_GET['term']) && ($keyword=trim($_GET['term']))!=='')
		{
			$tags=Tag::model()->suggestTags($keyword, Parameter::getValue(7), $_GET['lang']);
			echo CJSON::encode($tags);
		    Yii::app()->end();
		}
	}
	
	public function actionCategoriesByLanguage()
	{
		$categories = Category::model()->findAll(array('condition' => 'language =\'' . $_POST['Post']['language']. '\' AND category_id IS NULL','order' => 'LOWER(name) ASC'));
		$this->getListData($categories, 0);	
	}
	
	private function getListData($categories, $level)
	{			
		foreach($categories as $category)
		{
			$lines = '';
			for($i = 0; $i < $level; $i++)
				$lines .= '--';
			echo "<option value=\"{$category->id}\">{$lines}{$category->name}</option>";
			$this->getListData($category->categories, $level + 1);
		}		
	}
	
	public function actionGetMaxId()
	{
		if(isset($_POST['category']) && isset($_POST['language']))
		{
			$post = Post::model()->find(array('select' => 'MAX(id) as maxId', 'condition' => 'category_id = ? AND language = ?', 'params' => array($_POST['category'], $_POST['language'])));
			echo $post->maxId + 1;
		}		
	}

	public function actionSearch()
	{
		$match = '';
		
		if(isset($_GET['search']))
			$match = addcslashes($_GET['search'], '%_');

		$categories = substr(Category::getSubcategoriesIdsR(Category::model()->findAll(array('condition' => 'language =:language AND category_id IS NULL','order' => 'LOWER(name) ASC', 'params' => array(':language' => Yii::app()->getLanguage())))),1);
		$results = new CActiveDataProvider('Post',array(
            'criteria'=>array(                   
              	'order'=>'id',
				'condition' => '(title LIKE ? OR content LIKE ?) AND language = ? AND status=' . Post::STATUS_PUBLISHED . ' AND category_id IN(' . $categories . ')',
		        'params' => array("%$match%","%$match%",Yii::app()->getLanguage())	
            ),
			'pagination'=>array(
				'pageSize'=>Parameter::getValue(34),
			),
		));
		

		$this->render('searchResults', array('results' => $results));	
	}
}
