<?php
/**
 * Yii blog
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */
 
Yii::import('ext.EImageValidator');

class Language extends CActiveRecord
{
	public $image;
	public $oldcode;
	public static $IMAGE_DIRECTORY2;
	const IMAGE_DIRECTORY = 'images/flags/';

	public static function getImageDirectory()
	{
		return dirname(__FILE__) . '/../assets/' . self::IMAGE_DIRECTORY;
	}
	
	public function _construct()
	{
		Language::$IMAGE_DIRECTORY2 = Language::getImageDirectory();		
	}
		
	/**
	 * Returns the static model of the specified AR class.
	 * @return CActiveRecord the static model class
	 */
	public static function model($className=__CLASS__)
	{
		Language::$IMAGE_DIRECTORY2 = Language::getImageDirectory();		

		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{language}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		return array(
			array('code, name', 'required'),
			array('code', 'unique'),
            array('code', 'length', 'min'=>2, 'max'=>2),
        	array('image', 'EImageValidator', 'types'=>'gif', 'size' => 10, 'width' => 50, 'height' => 50, 'allowEmpty'=>true),
			array('code', 'match', 'pattern' => '/^[a-zA-Z\s]+$/', 'message' => 'Code must have letters only.'),
			array('name','filter','filter'=>array($obj=new CHtmlPurifier(),'purify')),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'code' => Message::getTranslation(41),
			'name' => Message::getTranslation(10),
			'image' => Message::getTranslation(42),
		);
	}
	
	/**
	 * Retrieves the list of categories based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the needed posts.
	 */
	public function search()
	{
		$criteria=new CDbCriteria;
		$criteria->compare('code',$this->code, true);
		$criteria->compare('name',$this->name, true);

		return new CActiveDataProvider('Language', array(
			'criteria'=>$criteria,
			'sort'=>array(
				'defaultOrder'=>'LOWER(code) ASC',
			),
			'pagination'=>array(
				'pageSize'=>Parameter::getValue(11),
			),
		));
	}
	
	public static function getLanguagesOptions()
	{
		return CHtml::listData(Language::model()->findAll(array('order' => 'code ASC')), 'code', 'name');
	}
	
	protected function beforeSave()
	{
		$this->code = trim(strtolower($this->code));
		$this->image=CUploadedFile::getInstance($this,'image');
		return true;
	}

	protected function afterSave()
	{
		if(!$this->isNewRecord && $this->code !== $this->oldcode)
		{
			if(file_exists(Language::$IMAGE_DIRECTORY2 . $this->oldcode . '.gif'))
				rename(Language::$IMAGE_DIRECTORY2 . $this->oldcode . '.gif', Language::$IMAGE_DIRECTORY2 . $this->code . '.gif');
		}
		if(!is_null($this->image))
		{
			if(file_exists(Language::$IMAGE_DIRECTORY2 . $this->oldcode . '.gif'))
				unlink(Language::$IMAGE_DIRECTORY2 . $this->oldcode . '.gif');
			$this->image->saveAs(Language::$IMAGE_DIRECTORY2 . $this->code . '.gif');
		}
	}
	
	protected function beforeDelete()
	{
		if(count(Post::model()->findAll('language =?', array($this->code))) == 0)
		{
			if(count(Category::model()->findAll('language =?', array($this->code))) == 0)
			{
				if(count(Message::model()->findAll('language =?', array($this->code))) == 0)
				{
					return true;
				}
			}
		}
		
		return false;
	}
	
	protected function afterDelete()
	{
		if(file_exists(Language::$IMAGE_DIRECTORY2 . $this->code . '.gif'))
			unlink(Language::$IMAGE_DIRECTORY2 . $this->code . '.gif');
	}

	public static function checkLanguage($language)
	{
		$languages = Language::model()->findAll('status = 1');	
		
		foreach($languages as $lang)
		{
			if($language === $lang->code)
				return true;	
		}
		return false;				
	}
	
	public static function getNavigatorLanguage()
	{
		$language = explode(',',$_SERVER['HTTP_ACCEPT_LANGUAGE']);
		$language = strtolower(substr(chop($language[0]),0,2));
		return $language;
	}
	
	public static function getNameFromCode($code)
	{
		$language = self::model()->find('code = ?', array($code));
		if(!is_null($language))
			return $language->name;
		else
			return null;
	}
}
	