<?php
/**
 * Yii blog
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2016 Oligalma
 * @license New BSD License
 */
 
class Message extends CActiveRecord
{
	private $oldId;
	private $oldLanguage;
	
	/**
	 * Returns the static model of the specified AR class.
	 * @return CActiveRecord the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{message}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		return array(
			array('id, language, translation', 'required'),
			array('id, language, translation', 'safe', 'on' => 'search'),
			array('id', 'numerical', 'min' => 1),
	        array('id', 'checkUniqueness')
		);
	}

	public function checkUniqueness($attribute,$params)
	{
		if($this->id !== $this->oldId || $this->language !== $this->oldLanguage)
		{
			$model = Message::model()->find('id = ? AND language = ?', array($this->id, $this->language));
			if($model != null)
				$this->addError('id',Message::getTranslation(188));
		}	
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'lang' => array(self::BELONGS_TO, 'Language', 'language'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => Message::getTranslation(27),
			'language' => Message::getTranslation(35),
			'translation' => Message::getTranslation(46),
		);
	}
	
	public static function getTranslation($id)
	{
		$translation = '';
		$message = Message::model()->find(array('condition' => 'id = :id AND language = :lang', 'params' => array(':id' => $id, ':lang' => Yii::app()->getLanguage())));
		if(is_null($message))
		{
			$message = Message::model()->findByPk(array('id' => $id, 'language' => Parameter::getValue(29)));
			if(is_null($message))
				$translation = "No message available";
			else
				$translation = $message->translation;		
		}
		else
		{
			$translation = $message->translation;
		}
		return $translation;
	}
	
	/**
	 * Retrieves the list of categories based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the needed posts.
	 */
	public function search()
	{
		$criteria=new CDbCriteria;
		$criteria->compare('id',$this->id);
		$criteria->compare('language',$this->language);
		$criteria->compare('translation',$this->translation, true);

		return new CActiveDataProvider('Message', array(
			'criteria'=>$criteria,
			'sort'=>array(
				'defaultOrder'=>'language, id ASC',
			),
			'pagination'=>array(
				'pageSize'=>Parameter::getValue(16),
			),
		));
	}
	
	public function afterFind()
	{
		$this->oldId = $this->id;
		$this->oldLanguage = $this->language;
	}
}
	